library(dplyr)
library(magrittr)
library(vegan)
library(tidyverse)




##################################################################################################
####Fisher's test for invasive vs each virulence factor
mr_data_2 <- read.csv("~/Downloads/MR_data_K & O Loci _1072.csv")


contingency_table_invas_yer <- table(mr_data_2$Invasive, mr_data_2$Yersiniabactin)
print(contingency_table_invas_yer)
result_invas_yer <- fisher.test(contingency_table_invas_yer)
print(result_invas_yer)


contingency_table_invas_coli <- table(mr_data_2$Invasive, mr_data_2$Colibactin)
print(contingency_table_invas_coli)
result_invas_coli <- fisher.test(contingency_table_invas_coli)
print(result_invas_coli)

contingency_table_invas_aero <- table(mr_data_2$Invasive, mr_data_2$Aerobactin)
print(contingency_table_invas_aero)
result_invas_aero <- fisher.test(contingency_table_invas_aero)
print(result_invas_aero)


contingency_table_invas_salmo <- table(mr_data_2$Invasive, mr_data_2$Salmochelin)
print(contingency_table_invas_salmo)
result_invas_salmo <- fisher.test(contingency_table_invas_salmo)
print(result_invas_salmo)



contingency_table_invas_rmpADC <- table(mr_data_2$Invasive, mr_data_2$RmpADC)
print(contingency_table_invas_rmpADC)
result_invas_rmpADC <- fisher.test(contingency_table_invas_rmpADC)
print(result_invas_rmpADC)


contingency_table_invas_rmpa2 <- table(mr_data_2$Invasive, mr_data_2$rmpA2)
print(contingency_table_invas_rmpa2)
result_invas_rmpa2 <- fisher.test(contingency_table_invas_rmpa2)
print(result_invas_rmpa2)

###############################################################################################

####Fisher's test for KL vs Invasive
mr_data_2 <- read.csv("~/Downloads/MR_data_K & O Loci _1072.csv")

# Step 2: List of K and O types for testing
k_types_of_interest <- c("KL64", "KL51","KL2","KL10")  # Add more as needed
o_types_of_interest <- c("O1/O2v1", "O1/O2v2", "OL101")  # Add more as needed

# Step 3: Perform Fisher's exact tests
for (k_locus in k_types_of_interest) {
  contingency_table_k <- table(mr_data_2$Invasive, mr_data_2$K_locus == k_locus)
  fisher_result_k <- fisher.test(contingency_table_k)
  
  p_value_k <- fisher_result_k$p.value
  
  # Print or store the results
  cat("Fisher's exact test for K-type", k_locus, ":", "\n")
  cat("P-value:", p_value_k, "\n\n")
}

####Fisher's test for OL vs Invasive

for (o_locus in o_types_of_interest) {
  contingency_table_o <- table(mr_data_2$Invasive, mr_data_2$O_locus == o_locus)
  fisher_result_o <- fisher.test(contingency_table_o)
  
  p_value_o <- fisher_result_o$p.value
  
  # Print or store the results
  cat("Fisher's exact test for O-type", o_locus, ":", "\n")
  cat("P-value:", p_value_o, "\n\n")
}


##############################################################################
####for KL vs STS

# Initialize an empty data frame to store results
fisher_test_results_st <- data.frame()

# Perform Fisher's exact test for each unique combination
for (st in unique(mr_data_2$ST)) {
  st_subset <- mr_data_2 %>%
    filter(ST == st)
  
  # Get unique combinations of ST and K_locus within the subset
  unique_combinations <- st_subset %>% distinct(ST, K_locus)
  
  # Perform Fisher's exact test for each unique combination within the subset
  for (i in 1:nrow(unique_combinations)) {
    k_locus <- unique_combinations[i, "K_locus"]
    
    # Create a subset for the current combination
    subset_df <- st_subset %>%
      filter(ST == st, K_locus == k_locus)
    
    # Check if the subset has at least two rows
    if (nrow(subset_df) >= 2) {
      # Create a contingency table directly from the subset
      contingency_table <- matrix(c(nrow(subset_df), 0, 0, 0), nrow = 2)
      colnames(contingency_table) <- c("Present", "Absent")
      rownames(contingency_table) <- c("ST", "Not ST")
      contingency_table[1, "Present"] <- sum(subset_df$K_locus == k_locus)
      contingency_table[2, "Absent"] <- sum(subset_df$K_locus != k_locus)
      
      # Perform Fisher's exact test
      result <- fisher.test(contingency_table)
      
      # Store the results in the data frame
      fisher_test_results_st <- bind_rows(fisher_test_results_st, data.frame(ST = st, K_locus = k_locus, p_value = result$p.value))
    }
  }
}


##################################################################################################################################################
#for OL vs carbapenem gens

#  Get unique elements in the K_locus column
unique_o_locus <- unique(mr_data_2$O_locus)

# Create an empty data frame to store results
results <- data.frame(O_locus = character(), P_value = numeric())


#  Perform Fisher's exact tests for each unique K_locus
for (o_locus in unique_o_locus) {
  contingency_table_o <- table(mr_data_2$Bla_Carb_acquired, mr_data_2$O_locus == o_locus)
  fisher_result_o <- fisher.test(contingency_table_o, simulate.p.value = TRUE)
  
  p_value_o <- fisher_result_o$p.value
  
  # Store the results in the data frame
  results_O <- rbind(results, data.frame(O_locus = o_locus, P_value = p_value_o))
}

print(results_O)


###############################################################################################
##for KL vs Ccarb

#  Get unique elements in the K_locus column
unique_k_locus <- unique(mr_data_2$K_locus)

# Create an empty data frame to store results
results_KL <- data.frame(K_locus = character(), P_value = numeric())

#  Perform Fisher's exact tests for each unique K_locus
for (k_locus in unique_k_locus) {
  contingency_table_k <- table(mr_data_2$Bla_Carb_acquired, mr_data_2$K_locus == k_locus)
  fisher_result_k <- fisher.test(contingency_table_k, simulate.p.value = TRUE)
  
  p_value_k <- fisher_result_k$p.value
  
  # Store the results in the data frame
  results_KL <- rbind(results_KL, data.frame(K_locus = k_locus, P_value = p_value_k))
}

print(results_KL)
#########################################################################################################
##Fisher's test for KL vs each Virulence factors

##Aerobactin
#  Get unique elements in the K_locus column
unique_k_locus <- unique(mr_data_2$K_locus)

# Create an empty data frame to store results
results_KL_aero <- data.frame(K_locus = character(), P_value = numeric())

#  Perform Fisher's exact tests for each unique K_locus
for (k_locus in unique_k_locus) {
  contingency_table_k <- table(mr_data_2$Aerobactin, mr_data_2$K_locus == k_locus)
  fisher_result_k <- fisher.test(contingency_table_k, simulate.p.value = TRUE)
  
  p_value_k <- fisher_result_k$p.value
  
  # Store the results in the data frame
  results_KL_aero <- rbind(results_KL_aero, data.frame(K_locus = k_locus, P_value = p_value_k))
}

print(results_KL_aero)

#####Yersiniabactin
#  Get unique elements in the K_locus column
unique_k_locus <- unique(mr_data_2$K_locus)

# Create an empty data frame to store results
results_KL_yer <- data.frame(K_locus = character(), P_value = numeric())

#  Perform Fisher's exact tests for each unique K_locus
for (k_locus in unique_k_locus) {
  contingency_table_k <- table(mr_data_2$Yersiniabactin, mr_data_2$K_locus == k_locus)
  fisher_result_k <- fisher.test(contingency_table_k, simulate.p.value = TRUE)
  
  p_value_k <- fisher_result_k$p.value
  
  # Store the results in the data frame
  results_KL_yer <- rbind(results_KL_yer, data.frame(K_locus = k_locus, P_value = p_value_k))
}

print(results_KL_yer)


#####Coliiabactin
#  Get unique elements in the K_locus column
unique_k_locus <- unique(mr_data_2$K_locus)

# Create an empty data frame to store results
results_KL_coli <- data.frame(K_locus = character(), P_value = numeric())

#  Perform Fisher's exact tests for each unique K_locus
for (k_locus in unique_k_locus) {
  contingency_table_k <- table(mr_data_2$Colibactin, mr_data_2$K_locus == k_locus)
  fisher_result_k <- fisher.test(contingency_table_k, simulate.p.value = TRUE)
  
  p_value_k <- fisher_result_k$p.value
  
  # Store the results in the data frame
  results_KL_coli <- rbind(results_KL_coli, data.frame(K_locus = k_locus, P_value = p_value_k))
}

print(results_KL_coli)

###


#####Salmochelin
#  Get unique elements in the K_locus column
unique_k_locus <- unique(mr_data_2$K_locus)

# Create an empty data frame to store results
results_KL_salmo <- data.frame(K_locus = character(), P_value = numeric())

#  Perform Fisher's exact tests for each unique K_locus
for (k_locus in unique_k_locus) {
  contingency_table_k <- table(mr_data_2$Salmochelin, mr_data_2$K_locus == k_locus)
  fisher_result_k <- fisher.test(contingency_table_k, simulate.p.value = TRUE)
  
  p_value_k <- fisher_result_k$p.value
  
  # Store the results in the data frame
  results_KL_salmo <- rbind(results_KL_salmo, data.frame(K_locus = k_locus, P_value = p_value_k))
}

print(results_KL_salmo)

###



#####rmpA2
#  Get unique elements in the K_locus column
unique_k_locus <- unique(mr_data_2$K_locus)

# Create an empty data frame to store results
results_KL_rmpA2 <- data.frame(K_locus = character(), P_value = numeric())

#  Perform Fisher's exact tests for each unique K_locus
for (k_locus in unique_k_locus) {
  contingency_table_k <- table(mr_data_2$rmpA2, mr_data_2$K_locus == k_locus)
  fisher_result_k <- fisher.test(contingency_table_k, simulate.p.value = TRUE)
  
  p_value_k <- fisher_result_k$p.value
  
  # Store the results in the data frame
  results_KL_rmpA2 <- rbind(results_KL_rmpA2, data.frame(K_locus = k_locus, P_value = p_value_k))
}

print(results_KL_rmpA2)

###


#####rmpADC
#  Get unique elements in the K_locus column
unique_k_locus <- unique(mr_data_2$K_locus)

# Create an empty data frame to store results
results_KL_rmpADC <- data.frame(K_locus = character(), P_value = numeric())

#  Perform Fisher's exact tests for each unique K_locus
for (k_locus in unique_k_locus) {
  contingency_table_k <- table(mr_data_2$RmpADC, mr_data_2$K_locus == k_locus)
  fisher_result_k <- fisher.test(contingency_table_k, simulate.p.value = TRUE)
  
  p_value_k <- fisher_result_k$p.value
  
  # Store the results in the data frame
  results_KL_rmpADC <- rbind(results_KL_rmpADC, data.frame(K_locus = k_locus, P_value = p_value_k))
}

print(results_KL_rmpADC)

###
