#adding both carb count and klocus count
library(ggplot2)
library(dplyr)
library(patchwork)

# Read data from CSV file (assuming the file is named 'kl_data.csv')
data_k <- read.csv("/media/varun/Varun_Personal/Varun/NIHR/Organism_Analysis/kpn_sravani/K&O_locus/kl_data.csv")

#for K Locus
sorted_data <- data_k %>% arrange(desc(count_of_k_locus))

# Calculate cumulative counts for both columns
sorted_data$cumulative_count_of_k_locus <- cumsum(sorted_data$count_of_k_locus)
#if else to count the rows of carb_resistance with no values as 0
sorted_data$cumulative_carb_resistance <- cumsum(ifelse(is.na(sorted_data$carb_resistance), 0, sorted_data$carb_resistance))

# Calculate cumulative percentages
sorted_data$cumulative_percentage_count <- (sorted_data$cumulative_count_of_k_locus / sum(sorted_data$count_of_k_locus)) * 100
total_carb_resistance <- sum(ifelse(is.na(sorted_data$carb_resistance) | sorted_data$carb_resistance == 0, 0, sorted_data$carb_resistance))
sorted_data$cumulative_percentage_carb <- (sorted_data$cumulative_carb_resistance / total_carb_resistance) * 100


# Plot the cumulative data as a line graph
k <- ggplot(sorted_data, aes(x = seq_along(K_locus))) +
  geom_line(aes(y = cumulative_percentage_count), color = "skyblue", size = 1, linetype = "solid") +
  geom_line(aes(y = cumulative_percentage_carb), color = "orange", size = 1, linetype = "dashed") +
  labs(x = "Number of K_Locus", y = "Cumulative Count", title = "Cumulative K Locus and Carb Resistance") +
  scale_x_continuous(breaks = seq(0, nrow(sorted_data), by = 10)) +
  theme_minimal()


#for O Locus

# Read data from CSV file (assuming the file is named 'kl_data.csv')
O_data <- read.csv("/media/varun/Varun_Personal/Varun/NIHR/Organism_Analysis/kpn_sravani/K&O_locus/ol_data.csv")

sorted_data_O <- O_data %>% arrange(desc(count_of_o_locus))

# Calculate cumulative counts for both columns
sorted_data_O$cumulative_count_of_o_locus <- cumsum(sorted_data_O$count_of_o_locus)
#if else to count the rows of carb_resistance with no values as 0
sorted_data_O$cumulative_carb_resistance <- cumsum(ifelse(is.na(sorted_data_O$carb_resistance), 0, sorted_data_O$carb_resistance))

# Calculate cumulative percentages
sorted_data_O$cumulative_percentage_count <- (sorted_data_O$cumulative_count_of_o_locus / sum(sorted_data_O$count_of_o_locus)) * 100
total_carb_resistance <- sum(ifelse(is.na(sorted_data_O$carb_resistance) | sorted_data_O$carb_resistance == 0, 0, sorted_data_O$carb_resistance))
sorted_data_O$cumulative_percentage_carb <- (sorted_data_O$cumulative_carb_resistance / total_carb_resistance) * 100


# Plot the cumulative data as a line graph
o <- ggplot(sorted_data_O, aes(x = seq_along(O_locus))) +
  geom_line(aes(y = cumulative_percentage_count), color = "skyblue", size = 1, linetype = "solid") +
  geom_line(aes(y = cumulative_percentage_carb), color = "orange", size = 1, linetype = "dashed") +
  labs(x = "Number of O_Locus", y = "Cumulative Count", title = "Cumulative O Locus and Carb Resistance") +
  scale_x_continuous(breaks = seq(0, nrow(sorted_data_O), by = 2)) +
  theme_minimal()

combined_plot <- k + o + plot_layout(ncol = 1)
print(combined_plot)
